# coding: utf-8

"""
    ThingsBoard REST API

    For instructions how to authorize requests please visit <a href='http://thingsboard.io/docs/reference/rest-api/'>REST API documentation page</a>.  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RuleChainData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'metadata': 'list[RuleChainMetaData]',
        'rule_chains': 'list[RuleChain]'
    }

    attribute_map = {
        'metadata': 'metadata',
        'rule_chains': 'ruleChains'
    }

    def __init__(self, metadata=None, rule_chains=None):  # noqa: E501
        """RuleChainData - a model defined in Swagger"""  # noqa: E501
        self._metadata = None
        self._rule_chains = None
        self.discriminator = None
        if metadata is not None:
            self.metadata = metadata
        if rule_chains is not None:
            self.rule_chains = rule_chains

    @property
    def metadata(self):
        """Gets the metadata of this RuleChainData.  # noqa: E501


        :return: The metadata of this RuleChainData.  # noqa: E501
        :rtype: list[RuleChainMetaData]
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this RuleChainData.


        :param metadata: The metadata of this RuleChainData.  # noqa: E501
        :type: list[RuleChainMetaData]
        """

        self._metadata = metadata

    @property
    def rule_chains(self):
        """Gets the rule_chains of this RuleChainData.  # noqa: E501


        :return: The rule_chains of this RuleChainData.  # noqa: E501
        :rtype: list[RuleChain]
        """
        return self._rule_chains

    @rule_chains.setter
    def rule_chains(self, rule_chains):
        """Sets the rule_chains of this RuleChainData.


        :param rule_chains: The rule_chains of this RuleChainData.  # noqa: E501
        :type: list[RuleChain]
        """

        self._rule_chains = rule_chains

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RuleChainData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RuleChainData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
